OC.L10N.register(
    "groupfolders",
    {
    "Team folders" : "Teammappen",
    "Denied (Inherited permission)" : "Geweigerd (Overgeërfde machtiging)",
    "Allowed (Inherited permission)" : "Toegelaten (Overgeërfde machtiging)",
    "Denied" : "Geweigerd",
    "Allowed" : "Toegelaten",
    "Access denied" : "Toegang geweigerd",
    "Inherit permission" : "Machtigingen overerven",
    "Deny" : "Weigeren",
    "Allow" : "Toestaan",
    "Group" : "Groep",
    "Team" : "Team",
    "Read" : "Lezen",
    "Write" : "Schrijven",
    "Create" : "Aanmaken",
    "Delete" : "verwijderen",
    "Share" : "Delen",
    "You" : "Jij",
    "Remove access rule" : "Verwijder toegangsregel",
    "Select a user or group" : "Kies een gebruiker of groep",
    "No Team folders yet" : "Nog geen teammappen",
    "Team folders will show up here" : "Teammappen worden hier getoond",
    "Add group" : "Groep toevoegen",
    "Default" : "Standaard",
    "Unlimited" : "Ongelimiteerd",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Weet je zeker dat je \"{folderName}\" en alle bestanden er in wilt wissen? Deze handeling kan niet ongedaan worden gemaakt.",
    "Delete \"{folderName}\"?" : "Verwijderen \"{folderName}\"?",
    "Folder name" : "Mapnaam",
    "Quota" : "Limieten",
    "Advanced Permissions" : "Geavanceerde Machtigingen",
    "Previous" : "Vorige",
    "Next" : "Volgende",
    "User" : "Gebruiker",
    "Unknown" : "Onbekend",
    "None" : "Geen",
    "{size} used" : "{size} gebruikt",
    "Other …" : "Overig...",
    "Unset" : "Schakel uit"
},
"nplurals=2; plural=(n != 1);");
